aboutsummaryrefslogtreecommitdiff
path: root/lib/transfer.c
diff options
context:
space:
mode:
Diffstat (limited to 'lib/transfer.c')
-rw-r--r--lib/transfer.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/transfer.c b/lib/transfer.c
index 740245e4b..6a93bf059 100644
--- a/lib/transfer.c
+++ b/lib/transfer.c
@@ -233,7 +233,7 @@ CURLcode Curl_fillreadbuffer(struct connectdata *conn, int bytes, int *nreadp)
#endif /* CURL_DOES_CONVERSIONS */
if((nread - hexlen) == 0)
/* mark this as done once this chunk is transfered */
data->req.upload_done = TRUE;
nread+=(int)strlen(endofline_native); /* for the added end of line */
@@ -2098,7 +2098,7 @@ CURLcode Curl_retry_request(struct connectdata *conn,
to retry. Marking it this way should
prevent i.e HTTP transfers to return
error just because nothing has been
- transfered! */
+ transferred! */
if(data->state.proto.http->writebytecount)
Curl_readrewind(conn);
@@ -233,7 +233,7 @@ CURLcode Curl_fillreadbuffer(struct connectdata *conn, int bytes, int *nreadp)
#endif /* CURL_DOES_CONVERSIONS */
if((nread - hexlen) == 0)
- /* mark this as done once this chunk is transfered */
+ /* mark this as done once this chunk is transferred */
data->req.upload_done = TRUE;
nread+=(int)strlen(endofline_native); /* for the added end of line */